pub struct LoopbackRedirect { /* private fields */ }Implementations
Sourceimpl LoopbackRedirect
impl LoopbackRedirect
Sourcepub async fn bind() -> Result<Self>
pub async fn bind() -> Result<Self>
Bind an ephemeral port.
Ephemeral by default so two Origin applications authorizing at the same time cannot collide.
Sourcepub async fn bind_port(port: u16) -> Result<Self>
pub async fn bind_port(port: u16) -> Result<Self>
Bind a fixed port, for providers that require the redirect URI to be registered in advance and reject a dynamic port.
pub fn with_timeout(self, timeout: Duration) -> Self